const receiver1 = 'eduarda.k@edu.pucrs.br';
const receiver2 = 'julia.makowski@edu.pucrs.br';

const senderEmail = Cypress.env('USER_EMAIL');
const genericPassword = Cypress.env('USER_PASSWORD');

describe('Feedbacks', () => {
  it('should send feedback correctly with message', () => {
    cy.login(senderEmail, genericPassword);
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Eduarda Keller').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.contains('Successo').should('be.visible');

    cy.get('.MuiSvgIcon-root[data-testid="HighlightOffIcon"]').click();
  });

  it('should send feedback correctly with empty message', () => {
    cy.login(senderEmail, genericPassword);
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Julia Makowski').click();

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.contains('Successo').should('be.visible');

    cy.get('.MuiSvgIcon-root[data-testid="HighlightOffIcon"]').click();
  });

  it('should not send feedback if value is invalid', () => {
    cy.login(senderEmail, genericPassword);
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#feedbackRecipientWrapper').click();
    cy.contains('Arthur Both').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('0');

    cy.get('#sendFeedbackButton').click();

    cy.get('.feedbackModal_sendClapFooterWrapper__poR_T > span')
      .should('be.visible')
      .should('have.text', 'Por favor, selecione a quantidade de aplausos');
  });

  it('should not send feedback if there is no receiver', () => {
    cy.login(senderEmail, genericPassword);
    cy.get('#userInfoCard', { timeout: 10000 }).should('be.visible').click();
    cy.get('#message').click().type('Essa é uma mensagem de teste');

    cy.get('[class*="feedbackModal_applauseWrapper"]').find('input').type('1');
    cy.get('#sendFeedbackButton').click();

    cy.get('#feedbackRecipientWrapper > span')
      .should('be.visible')
      .should(
        'have.text',
        'Por favor, selecione um destinatário para o feedback',
      );
  });

  it('should delete a received feedback', () => {
    cy.login(receiver1, genericPassword);
    cy.get('[class*="home_contentBox"]', { timeout: 10000 });
    cy.get('[id="feedback0"]', { timeout: 10000 })
      .should('be.visible')
      .then(() => {
        cy.get('[data-testid="DeleteOutlineOutlinedIcon"]').first().click();
        cy.get('#buttonConfirmar').click();
        cy.contains('Successo').should('be.visible');
        cy.get('[data-testid="HighlightOffIcon"]').click();
      });
  });

  it('should cancel a deletion of received feedback', () => {
    cy.login(receiver2, genericPassword);
    let initialFeedbacks: number = 0;
    cy.get('[class*="home_contentBox"]', { timeout: 10000 });
    cy.get('[id="feedback0"]', { timeout: 10000 })
      .should('be.visible')
      .its('length')
      .then((length) => {
        initialFeedbacks = length as number;
      })
      .then(() => {
        cy.get('[data-testid="DeleteOutlineOutlinedIcon"]').first().click();
        cy.get('#buttonCancelar').click();
        cy.get('.userMessageModal_modal__6hn13').should('not.exist');
        cy.get('[class*="home_contentBox"]');
        cy.get('[id="feedback0"]')
          .should('be.visible')
          .its('length')
          .should('eq', initialFeedbacks);
      });
  });
});
